## Copyright (C) 2018 jdonoghue
## 
## This program is free software: you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation, either version 3 of the License, or
## (at your option) any later version.
## 
## This program is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
## 
## You should have received a copy of the GNU General Public License
## along with this program.  If not, see
## <https://www.gnu.org/licenses/>.

## -*- texinfo -*- 
## @deftypefn {} {} writeDigitalPin (@var{obj}, @var{pin}, @var{value})
## Write digital value @var{value} to digital I/O @var{pin}.
##
## pin is a string name of the pin to write to.
## value is the logicl value (0, 1, true false) to write to the pin
##
## example
## a = arduino();
## writeDigitalPin(a,'D5',1);
## @seealso{}
## @end deftypefn

## Author: jdonoghue <jdonoghue@JYRW4S1>
## Created: 2018-05-15

function writePWMDutyCycle (obj, pin, value)
  if nargin < 3
    error ("@arduino.writePWMDutyCycle: expected pin name and value");
  endif
  if !ischar(pin) && !isnumeric(pin)
    error ("@arduino.writeDigitalPin: expected pin name as string");
  endif
  if (!isnumeric(value) || value > 1.0 || value < 0)
    error ("@arduino.writeDigitalPin: expected value between 0 .. 1");
  endif  
  
  pininfo = obj.get_pin(pin);

  # first use ?
  if strcmp(pininfo.mode, "unset")
    configurePin(obj, pin, "pwm")
  else
    [pinstate, pinmode] = pinStateMode(pininfo.mode);
    if !strcmp(pinmode, "pwm")
      error ("writeDigitalPin: pin is in incompatable mode");
    endif
  endif

  val = 255*value;

  datain = uint8([pininfo.id val]);
  
  [dataout, status] = __sendCommand__ (obj, ARDUINO_PWM, datain);
  
  if status != 0
    error ("writeDigitalPin: failed to set pin state err=%d", status);
  endif 
  
endfunction
